package com.cloupia.feature.compute.api.reports;


import com.cloupia.feature.compute.constants.ComputeConstants;
import com.cloupia.model.cIM.DynReportContext;
import com.cloupia.model.cIM.ReportContextRegistry;
import com.cloupia.service.cIM.inframgr.reportengine.ContextMapRule;
import com.cloupia.service.cIM.inframgr.reports.simplified.CloupiaReportAction;
import com.cloupia.service.cIM.inframgr.reports.simplified.CloupiaReportWithActions;

/**
 * This is just a report I'm using to demonstrate how you would show REST Adaptor based APIs created data in GUI.
 *
 */
public class ComputeAccountAPIsReport extends CloupiaReportWithActions {
	
	private static final String NAME = "compute.account.api.sample.report";
	private static final String LABEL = "Compute APIs Report";
	
	public ComputeAccountAPIsReport() {
		super();
		//IMPORTANT: this tells the framework which column of this report you want to pass as the report context id
		//when there is a UI action being launched in this report
		this.setMgmtColumnIndex(0);
		
	}

	@Override
	public CloupiaReportAction[] getActions() {
		return null;
	}

	@Override
	public Class getImplementationClass() {
		//this class handles all the report generation logic, look here for more details
		return ComputeAccountAPIsReportImpl.class;
	}

	@Override
	public String getReportLabel() {
		return LABEL;
	}

	@Override
	public String getReportName() {
		return NAME;
	}

	//this is important, make sure this returns false.  isEasyReport should ONLY return
	//true if and only if you're using the POJO approach, which we aren't in this case.
	@Override
	public boolean isEasyReport() {
		return false;
	}

	//make sure to return true in this case, as there are no drill down reports
	@Override
	public boolean isLeafReport() {
		return true;
	}
	
	//basically hardcoding it so this report will show in the location i want it to
		//Physcial -> Storage -> LH Menu Tree Provider is 51.
		//Physcial -> Compute -> LH Menu Tree Provider is 50.
		//Physcial -> Network -> LH Menu Tree Provider is 52
		@Override
		public int getMenuID() {
			return 50;// FooConstants.DUMMY_MENU_1;
		}
	
	@Override
	public ContextMapRule[] getMapRules() {
		//i'm using an autogenerated report context (which I registered in StorageModule), as mentioned in documentation
		//the type may vary depending on deployments, so the safest way to retrieve the auto generated type value
		//is to use the getContextByName api!
		DynReportContext dummyContextOneType = ReportContextRegistry.getInstance().getContextByName(ComputeConstants.INFRA_ACCOUNT_TYPE);
		ContextMapRule rule = new ContextMapRule();
		rule.setContextName(dummyContextOneType.getId());
		rule.setContextType(dummyContextOneType.getType());
		
		ContextMapRule[] rules = new ContextMapRule[1];
		rules[0] = rule;
		
		return rules;
	}

}
