package com.cloupia.feature.foo.accounts;

import com.cloupia.feature.foo.accounts.pagination.FooAccountReportHandler;
import com.cloupia.feature.foo.constants.FooConstants;
import com.cloupia.feature.foo.actions.SimpleDummyAction;
import com.cloupia.model.cIM.DynReportContext;
import com.cloupia.model.cIM.ReportContextRegistry;
import com.cloupia.model.cIM.ReportDefinition;
import com.cloupia.service.cIM.inframgr.reportengine.ContextMapRule;
import com.cloupia.service.cIM.inframgr.reports.simplified.CloupiaReportAction;
import com.cloupia.service.cIM.inframgr.reports.simplified.CloupiaReportWithActions;

/**
 * This is just a dummy report I'm using to demonstrate how you would place a report under a new menu location
 * for a specific context.  In this case, I have a new menu "dummy_menu_1" and this menu also has a new context
 * "dummy context one", this report does a couple of things to make sure it gets placed into that specific
 * location.
 *
 */
public class FooAccountSampleReport extends CloupiaReportWithActions {
	
	private static final String NAME = "foo.account.sample.report";
	private static final String LABEL = "Foo Account Sample";
	
	public FooAccountSampleReport() {
		super();
		//IMPORTANT: this tells the framework which column of this report you want to pass as the report context id
		//when there is a UI action being launched in this report
		this.setMgmtColumnIndex(0);
		
		//you can technically speaking set the proper menu id and context map rules here in the
		//the constructor BUT i think it's better to override the functions and hardcode this logic into the function 
		//instead (as shown below), just to guarantee it can't be tweaked by anyone else!
		
		
	}

	@Override
	public CloupiaReportAction[] getActions() {
		CloupiaReportAction actions[] = new CloupiaReportAction[1];
		actions[0] = new SimpleDummyAction();
		
		return actions;
	}

	@Override
	public Class getImplementationClass() {
		//this class handles all the report generation logic, look here for more details
		return FooAccountSampleReportImpl.class;
	}

	@Override
	public String getReportLabel() {
		return LABEL;
	}

	@Override
	public String getReportName() {
		return NAME;
	}

	//this is important, make sure this returns false.  isEasyReport should ONLY return
	//true if and only if you're using the POJO approach, which we aren't in this case.
	@Override
	public boolean isEasyReport() {
		return false;
	}

	//make sure to return true in this case, as there are no drill down reports
	@Override
	public boolean isLeafReport() {
		return false;
	}
	
	//basically hardcoding it so this report will show in the location i want it to
	//Physcial -> Storage -> LH Menu Tree Provider is 51.
	//Physcial -> Compute -> LH Menu Tree Provider is 50.
	//Physcial -> Network -> LH Menu Tree Provider is 52
	@Override
	public int getMenuID() {
		return 51;// FooConstants.DUMMY_MENU_1;
	}
	
	@Override
	public ContextMapRule[] getMapRules() {
		//i'm using an autogenerated report context (which I registered in FooModule), as mentioned in documentation
		//the type may vary depending on deployments, so the safest way to retrieve the auto generated type value
		//is to use the getContextByName api!
		DynReportContext dummyContextOneType = ReportContextRegistry.getInstance().getContextByName(FooConstants.INFRA_ACCOUNT_TYPE);
		ContextMapRule rule = new ContextMapRule();
		rule.setContextName(dummyContextOneType.getId());
		rule.setContextType(dummyContextOneType.getType());
		
		ContextMapRule[] rules = new ContextMapRule[1];
		rules[0] = rule;
		
		return rules;
	}
	/*
	 * Below  methods
	 * getPaginationModelClass, 
	 * getPaginationProvider, 
	 * isPaginated,
	 * and getReportHint
	 * are added for the Pagination support
	 */
	
	/*
	 * This method is used to get the Model class for the Pagination support
	 * @return Class This returns Paginated Report Model class
	 */
	@Override
	public Class getPaginationModelClass() {
		// TODO Auto-generated method stub
		return DummyAccount.class;
	}

	/*
	 * This method is used to get the Pagination Handler class for the Pagination support
	 * @return Class This returns Pagination handler class
	 */
	@Override
	public Class getPaginationProvider() {
		// TODO Auto-generated method stub
		return FooAccountReportHandler.class;
	}

	/*
	 * This method is used to check whether the report is Pagination or not.
	 * @return boolean This returns true(if it is pagination supported report)
	 */
	@Override
	public boolean isPaginated() {
		// TODO Auto-generated method stub
		return true;
	}
	/*
	 * This method is used to get ReportHint type.
	 * If the report type  is pagination,explicitly we have to specify the return type as ReportDefinition.REPORT_HINT_PAGINATED_TABLE.
	 * @return int This returns PaginationHint 
	 */
	@Override
	public int getReportHint(){
		return ReportDefinition.REPORT_HINT_PAGINATED_TABLE;
	}

}
