package com.cloupia.feature.foo.api.tasks;

import java.util.List;

import org.apache.log4j.Logger;

import com.cloupia.feature.foo.api.config.DummyAccountConfig;
import com.cloupia.feature.foo.api.config.DummyAccountCreateConfig;
import com.cloupia.feature.foo.constants.FooConstants;
import com.cloupia.fw.objstore.ObjStore;
import com.cloupia.fw.objstore.ObjStoreHelper;
import com.cloupia.service.cIM.inframgr.AbstractTask;
import com.cloupia.service.cIM.inframgr.TaskConfigIf;
import com.cloupia.service.cIM.inframgr.TaskOutputDefinition;
import com.cloupia.service.cIM.inframgr.customactions.CustomActionLogger;
import com.cloupia.service.cIM.inframgr.customactions.CustomActionTriggerContext;

public class CreateOAAPITask extends AbstractTask {

	static Logger logger = Logger.getLogger(CreateOAAPITask.class);

	@Override
	public void executeCustomAction(CustomActionTriggerContext context, CustomActionLogger actionLogger)
			throws Exception {

		DummyAccountCreateConfig oldDef = (DummyAccountCreateConfig) context.loadConfigObject();
		String accountName = oldDef.getAccountName();
		try {
			DummyAccountConfig config = new DummyAccountConfig();
			config.setAccountName(accountName);
			config.setDesc(oldDef.getDesc());
			config.setIp(oldDef.getIp());
			config.setStatus(oldDef.getStatus());
			ObjStore<DummyAccountConfig> store = ObjStoreHelper.getStore(DummyAccountConfig.class);
			List<DummyAccountConfig> list = store.query("accountName == '" + accountName + "'");
			if (list == null || list.isEmpty()) {
				store.insert(config);
			} else {
				throw new Exception("account " + accountName + " already exists.");
			}

			context.saveOutputValue(FooConstants.DUMMY_ACCOUNT_NAME_OUTPUT, oldDef.getAccountName());
			actionLogger.addInfo("DummyAccount " + oldDef.getAccountName() + " added Successfully");

		} catch (Exception e) {
			actionLogger.addError("failed to Create Dummy Account"+e);
			logger.error("failed to Create Dummy Account ", e);
			if(!(context.getExternalContext() == CustomActionTriggerContext.REST_CONTEXT))
			context.exit();
			
		}
	}

	@Override
	public TaskConfigIf getTaskConfigImplementation() {
		return new DummyAccountCreateConfig();
	}

	@Override
	public String getTaskName() {
		return DummyAccountCreateConfig.HANDLER_LABEL;// DummyAccount.MODIFY_HANDLER_NAME;
	}

	@Override
	public TaskOutputDefinition[] getTaskOutputDefinitions() {
		TaskOutputDefinition[] output = new TaskOutputDefinition[1];
		// NOTE: If you want to use the output of this task as input to another
		// task. Then the second argument
		// of the output definition MUST MATCH the type of UserInputField in the
		// config of the task that will
		// be receiving this output. Take a look at HelloWorldConfig as an
		// example.
		output[0] = new TaskOutputDefinition(FooConstants.DUMMY_ACCOUNT_NAME_OUTPUT,
				FooConstants.DUMMY_ACCOUNT_NAME_OUTPUT, "Account Name");

		return output;
	}

}
