package com.cloupia.feature.foo.api.tasks;

import java.util.List;

import org.apache.log4j.Logger;

import com.cloupia.feature.foo.api.config.DummyAccountConfig;
import com.cloupia.feature.foo.api.config.DummyAccountDeleteConfig;
import com.cloupia.feature.foo.constants.FooConstants;
import com.cloupia.fw.objstore.ObjStore;
import com.cloupia.fw.objstore.ObjStoreHelper;
import com.cloupia.service.cIM.inframgr.AbstractTask;
import com.cloupia.service.cIM.inframgr.TaskConfigIf;
import com.cloupia.service.cIM.inframgr.TaskOutputDefinition;
import com.cloupia.service.cIM.inframgr.customactions.CustomActionLogger;
import com.cloupia.service.cIM.inframgr.customactions.CustomActionTriggerContext;

public class DeleteOAAPITask extends AbstractTask {

	static Logger logger = Logger.getLogger(DeleteOAAPITask.class);

	@Override
	public void executeCustomAction(CustomActionTriggerContext context, CustomActionLogger actionLogger)
			throws Exception {

		DummyAccountDeleteConfig oldDef = (DummyAccountDeleteConfig) context.loadConfigObject();
		String accountName = oldDef.getAccountName();

		ObjStore<DummyAccountConfig> store = ObjStoreHelper.getStore(DummyAccountConfig.class);
		List<DummyAccountConfig> list = store.query("accountName == '" + accountName + "'");
		if (list == null || list.isEmpty()) {
			actionLogger.addInfo("No account found with this name:" + accountName);
			throw new Exception("No account found with this name:" + accountName);
		}
		try {
			String filter = "accountName == '" + accountName + "'";
			store.delete(filter);
			context.saveOutputValue(FooConstants.DUMMY_ACCOUNT_NAME_OUTPUT, oldDef.getAccountName());
			actionLogger.addInfo("DummyAccount " + oldDef.getAccountName() + " deleted  Successfully");
		} catch (Exception e) {
			actionLogger.addInfo("failed to Delete Dummy Account" + e);
			logger.error("failed to Delete Dummy Account", e);
			if (!(context.getExternalContext() == CustomActionTriggerContext.REST_CONTEXT))
				context.exit();
		}

	}

	@Override
	public TaskConfigIf getTaskConfigImplementation() {
		return new DummyAccountDeleteConfig();
	}

	@Override
	public String getTaskName() {
		return DummyAccountDeleteConfig.HANDLER_NAME;
	}

	@Override
	public TaskOutputDefinition[] getTaskOutputDefinitions() {
		TaskOutputDefinition[] output = new TaskOutputDefinition[1];
		// NOTE: If you want to use the output of this task as input to another
		// task. Then the second argument
		// of the output definition MUST MATCH the type of UserInputField in the
		// config of the task that will
		// be receiving this output. Take a look at HelloWorldConfig as an
		// example.
		output[0] = new TaskOutputDefinition(FooConstants.DUMMY_ACCOUNT_NAME_OUTPUT,
				FooConstants.DUMMY_ACCOUNT_NAME_OUTPUT, "Account Name");

		return output;
	}

}
