package com.cloupia.feature.foo.api.tasks;

import java.util.List;

import org.apache.log4j.Logger;

import com.cloupia.feature.foo.api.config.DummyAccountConfig;
import com.cloupia.feature.foo.api.config.DummyAccountUpdateConfig;
import com.cloupia.feature.foo.constants.FooConstants;
import com.cloupia.fw.objstore.ObjStore;
import com.cloupia.fw.objstore.ObjStoreHelper;
import com.cloupia.service.cIM.inframgr.AbstractTask;
import com.cloupia.service.cIM.inframgr.TaskConfigIf;
import com.cloupia.service.cIM.inframgr.TaskOutputDefinition;
import com.cloupia.service.cIM.inframgr.customactions.CustomActionLogger;
import com.cloupia.service.cIM.inframgr.customactions.CustomActionTriggerContext;

public class UpdateOAAPITask extends AbstractTask {

	static Logger logger = Logger.getLogger(UpdateOAAPITask.class);

	@Override
	public void executeCustomAction(CustomActionTriggerContext context, CustomActionLogger actionLogger)
			throws Exception {

		DummyAccountUpdateConfig oldDef = (DummyAccountUpdateConfig) context.loadConfigObject();
		ObjStore<DummyAccountConfig> store = ObjStoreHelper.getStore(DummyAccountConfig.class);
		String accountName = oldDef.getAccountName();

		DummyAccountConfig acc = new DummyAccountConfig();
		acc.setAccountName(accountName);
		acc.setStatus(oldDef.getStatus());
		acc.setIp(oldDef.getIp());
		List<DummyAccountConfig> list = store.query("accountName == '" + accountName + "'");
		if (list == null || list.isEmpty()) {
			actionLogger.addInfo("No account found with this name:" + accountName);
			throw new Exception("No account found with this name:" + accountName);
		}

		try {

			String query = "accountName == '" + oldDef.getAccountName() + "'";
			store.modifySingleObject(query, acc);
			
			context.saveOutputValue(FooConstants.DUMMY_ACCOUNT_NAME_OUTPUT, oldDef.getAccountName());
			actionLogger.addInfo("Dummy Account " + oldDef.getAccountName() + " modified Successfully");

		} catch (Exception e) {
			actionLogger.addInfo("failed to Update Dummy Account");
			logger.error("failed to Update Dummy Account", e);
			if(!(context.getExternalContext() == CustomActionTriggerContext.REST_CONTEXT))
				context.exit();
		}
		
	}

	@Override
	public TaskConfigIf getTaskConfigImplementation() {
		return new DummyAccountUpdateConfig();
	}

	@Override
	public String getTaskName() {
		return DummyAccountUpdateConfig.MODIFY_HANDLER_NAME;
	}

	@Override
	public TaskOutputDefinition[] getTaskOutputDefinitions() {
		TaskOutputDefinition[] output = new TaskOutputDefinition[1];
		// NOTE: If you want to use the output of this task as input to another
		// task. Then the second argument
		// of the output definition MUST MATCH the type of UserInputField in the
		// config of the task that will
		// be receiving this output. Take a look at HelloWorldConfig as an
		// example.
		output[0] = new TaskOutputDefinition(FooConstants.DUMMY_ACCOUNT_NAME_OUTPUT,
				FooConstants.DUMMY_ACCOUNT_NAME_OUTPUT, "Account Name");
		return output;
	}

}
