package com.cloupia.feature.foo.formfields;

import com.cloupia.feature.foo.accounts.DummyAccount;
import com.cloupia.feature.foo.accounts.pagination.FooAccountReportHandler;
import com.cloupia.feature.foo.constants.FooConstants;
import com.cloupia.model.cIM.DynReportContext;
import com.cloupia.model.cIM.ReportContextRegistry;
import com.cloupia.model.cIM.ReportDefinition;
import com.cloupia.service.cIM.inframgr.reportengine.ContextMapRule;
import com.cloupia.service.cIM.inframgr.reports.simplified.CloupiaReportAction;
import com.cloupia.service.cIM.inframgr.reports.simplified.CloupiaReportWithActions;

/**
 * This example demonstrates how to develop a report programmatically.  
 * I'm extending CloupiaReportWithActions, this is the base class you should use for programmatic reports.
 * I'm providing my own implementation class, take a look in DummyVLANsReportImpl.java for more detail.
 *
 */
public class SimpleFormFieldsReport extends CloupiaReportWithActions {
	
	private static final String NAME = "foo.formfields.report";
	private static final String LABEL = "Sample FormFields";
	
	public SimpleFormFieldsReport() {
		super();
		//IMPORTANT: this tells the framework which column of this report you want to pass as the report context id
		//when there is a UI action being launched in this report
		this.setMgmtColumnIndex(0);

		
	}

	@Override
	public CloupiaReportAction[] getActions() {
		SimpleFormFieldsAction dummyAction = new SimpleFormFieldsAction();
		CloupiaReportAction[] actions = new CloupiaReportAction[1];
		actions[0] = dummyAction;
		return actions;
	}

	@Override
	public Class getImplementationClass() {
		//this class handles all the report generation logic, look here for more details
		return SimpleFormFieldsReportImpl.class;
	}

	@Override
	public String getReportLabel() {
		return LABEL;
	}

	@Override
	public String getReportName() {
		return NAME;
	}

	//this is important, make sure this returns false.  isEasyReport should ONLY return
	//true if and only if you're using the POJO approach, which we aren't in this case.
	@Override
	public boolean isEasyReport() {
		return false;
	}
	@Override
	public int getMenuID() {
		return 51;// FooConstants.DUMMY_MENU_1;
	}
	//make sure to return true in this case, as there are no drill down reports
	@Override
	public boolean isLeafReport() {
		return true;
	}
	@Override
	public ContextMapRule[] getMapRules() {
		//i'm using an autogenerated report context (which I registered in StorageModule), as mentioned in documentation
		//the type may vary depending on deployments, so the safest way to retrieve the auto generated type value
		//is to use the getContextByName api!
		DynReportContext dummyContextOneType = ReportContextRegistry.getInstance().getContextByName(FooConstants.INFRA_ACCOUNT_TYPE);
		ContextMapRule rule = new ContextMapRule();
		rule.setContextName(dummyContextOneType.getId());
		rule.setContextType(dummyContextOneType.getType());
		
		ContextMapRule[] rules = new ContextMapRule[1];
		rules[0] = rule;
		
		return rules;
	}
	/*
	 * Below  methods
	 * getPaginationModelClass, 
	 * getPaginationProvider, 
	 * isPaginated,
	 * and getReportHint
	 * are added for the Pagination support
	 */
	
	/*
	 * This method is used to get the Model class for the Pagination support
	 * @return Class This returns Paginated Report Model class
	 */
	@Override
	public Class getPaginationModelClass() {
		// TODO Auto-generated method stub
		return DummyAccount.class;
	}

	/*
	 * This method is used to get the Pagination Handler class for the Pagination support
	 * @return Class This returns Pagination handler class
	 */
	@Override
	public Class getPaginationProvider() {
		// TODO Auto-generated method stub
		return FooAccountReportHandler.class;
	}

	/*
	 * This method is used to check whether the report is Pagination or not.
	 * @return boolean This returns true(if it is pagination supported report)
	 */
	@Override
	public boolean isPaginated() {
		// TODO Auto-generated method stub
		return true;
	}
	/*
	 * This method is used to get ReportHint type.
	 * If the report type  is pagination,explicitly we have to specify the return type as ReportDefinition.REPORT_HINT_PAGINATED_TABLE.
	 * @return int This returns PaginationHint 
	 */
	@Override
	public int getReportHint(){
		return ReportDefinition.REPORT_HINT_PAGINATED_TABLE;
	}


}

